@@ -185,9 +185,18 @@ def output_check_results(job_name, checks_data, check_results, checks_out_dir):
     Handle all output from checks
     This includes both terminal output, and saving figures
     """
+    # Save histograms in a root file
+    hist_out_path = f"{job_name}_histograms.root"
+    hist_to_root(job_name, check_results, hist_out_path)
+
+    # Save check results to JSON file
     check_results_with_job = {job_name: check_results}
     json_out_path = join(checks_out_dir, "checks.json")
-    checks_to_JSON(checks_data, check_results_with_job, json_output_path=json_out_path)
+    checks_to_JSON(
+        checks_data,
+        check_results_with_job,
+        json_output_path=json_out_path,
+    )
 
     for cr in check_results:
         if check_results[cr].passed:
@@ -213,8 +222,6 @@ def output_check_results(job_name, checks_data, check_results, checks_out_dir):
                     tree_name = "_".join(key.split("/"))
                     fig_name = f"{job_name}_{tree_name}_{cr}_{hist_counter-1}.pdf"
                     plt.savefig(join(checks_out_dir, fig_name))
-            # Save histograms in a root file
-            hist_to_root(job_name, check_results[cr], checks_out_dir)
         else:
             click.secho(f"Check '{cr}' failed!", fg="red")
         for msg in check_results[cr].messages:
